# PipelineGazpromInfotech library

[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/vb64/pipeline.gazprom.infotech/pep257.yml?label=Pep257&style=plastic&branch=main)](https://github.com/vb64/pipeline.gazprom.infotech/actions?query=workflow%3Apep257)
[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/vb64/pipeline.gazprom.infotech/py3.yml?label=Python%203.8-3.13&style=plastic&branch=main)](https://github.com/vb64/pipeline.gazprom.infotech/actions?query=workflow%3Apy3)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/6a82eaf82a6448f9ac8e9b73f8976eb2)](https://app.codacy.com/gh/vb64/pipeline.gazprom.infotech/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_coverage)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/6a82eaf82a6448f9ac8e9b73f8976eb2)](https://app.codacy.com/gh/vb64/pipeline.gazprom.infotech/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

The free, open source PipelineGazpromInfotech library is designed to making infotech.xml files.

## Installation

```bash
pip install pipeline-gazprom-infotech
```

## Development

```bash
git clone git@github.com:vb64/pipeline.gazprom.infotech.git
cd pipeline.gazprom.infotech
make setup PYTHON_BIN=/path/to/python3
make tests
```
